/**
 * Created by lcg on 2016/10/15.
 */

import React, { Component } from "react";
import {
    StyleSheet,
    ScrollView,
    Image,
    TouchableWithoutFeedback
} from "react-native";

const PRESS_DELAY = 800;
const DOUBLE_TAPS = 300;

class ImageViewer extends Component {
    constructor(props) {
        super(props);

        this.state = { contentSize: { width: 0, height: 0 } };
    }

    componentDidMount(){
        const self = this;
        Image.getSize(this.props.uri,
            (width,height) => {
                self.setState({ contentSize: {width:10,height:10}});
            },
            (error) => {
                console.log("Get Image Size Failed:",error);
            });
    }

    _onLayout(e){
        this.setState({containerSize: {
            width: e.nativeEvent.layout.width,
            height: e.nativeEvent.layout.height
        }});
    }

    render(){
        return (
            <ScrollView
                onLayout={this._onLayout.bind(this)}
                style={[this.props.style,styles.container]}
                contentContainerStyle={this.state.contentSize}
                onTouchStart={this._onTouchStart.bind(this)}
                onTouchMove={this._onTouchMove.bind(this)}
                onTouchEnd={this._onTouchEnd.bind(this)}>
                    <Image source={{uri:this.props.uri}} style={this.state.contentSize} />
            </ScrollView>
        );
    }

    _onTouchStart(){
        this._touchStart = new Date().getTime();
        this._touchStartTimer && clearTimeout(this._touchStartTimer);
        const self = this;
        this._touchStartTimer = setTimeout(() => {
            self._touchStart = null;

            self._onLongPress && self._onLongPress();
        },PRESS_DELAY);
    }

    _onTouchMove(){
        this._touchStart = null;
        this._touchStartTimer && clearTimeout(this._touchStartTimer);
    }

    _onTouchEnd(){
        if (this._touchStart){
            let touchEnd = new Date().getTime();
            if (touchEnd - this._touchStart < PRESS_DELAY){
                this._onPress && this._onPress();
            }

            this._touchStart = null;
        }

        this._touchStartTimer && clearTimeout(this._touchStartTimer);
    }

    _onPress(){
        let pressTime = new Date().getTime();
        if (this._pressTime){
            if ( pressTime - this._pressTime < DOUBLE_TAPS){
                this._pressTimer && clearTimeout(this._pressTimer);
                this._onDoubleTaps();
                this._pressTime = null;
                return ;
            }
        }

        this._pressTime = pressTime;

        const self = this;
        this._pressTimer && clearTimeout(this._pressTimer);
        this._pressTimer = setTimeout(() => {
            self.props.onPress && self.props.onPress();
            self._pressTime = null;
            // console.log("press");
        },DOUBLE_TAPS);
    }

    _onLongPress(){
        this.props.onLongPress && this.props.onLongPress();
        // console.log("long press");
    }

    _onDoubleTaps(){
        this.props.onDoubleTaps && this.props.onDoubleTaps();
        // console.log("double taps");
    }
}

const styles = StyleSheet.create({
    container: {
        backgroundColor: 'black'
    }
});

export { ImageViewer };